import pygame

class App:
    def __init__(self, title="pyguiEZ App", size=(400, 300)):
        pygame.init()
        self.screen = pygame.display.set_mode(size)
        pygame.display.set_caption(title)
        self.running = True
        self.widgets = []

    def add_widget(self, widget):
        self.widgets.append(widget)

    def run(self):
        while self.running:
            self.screen.fill((255, 255, 255))
            for event in pygame.event.get():
                if event.type == pygame.QUIT:
                    self.running = False
                for widget in self.widgets:
                    widget.handle_event(event)

            for widget in self.widgets:
                widget.draw(self.screen)

            pygame.display.flip()

        pygame.quit()



import pygame

class Button:
    def __init__(self, app, text, pos=(10, 50), size=(120, 40), command=None):
        self.text = text
        self.rect = pygame.Rect(pos, size)
        self.command = command
        self.font = pygame.font.SysFont(None, 24)
        app.add_widget(self)

    def draw(self, surface):
        pygame.draw.rect(surface, (180, 180, 180), self.rect)
        text_surf = self.font.render(self.text, True, (0, 0, 0))
        text_rect = text_surf.get_rect(center=self.rect.center)
        surface.blit(text_surf, text_rect)

    def handle_event(self, event):
        if event.type == pygame.MOUSEBUTTONDOWN:
            if self.rect.collidepoint(event.pos) and self.command:
                self.command()



import pygame

class Label:
    def __init__(self, app, text, pos=(10, 10), font_size=24):
        self.text = text
        self.font = pygame.font.SysFont(None, font_size)
        self.pos = pos
        app.add_widget(self)

    def set_text(self, new_text):
        self.text = new_text

    def draw(self, surface):
        text_surf = self.font.render(self.text, True, (0, 0, 0))
        surface.blit(text_surf, self.pos)

    def handle_event(self, event):
        pass
